@@ -640,23 +640,23 @@ void         ssl_callback_LogTracingState(SSL *, int, int);
 
 /*  Session Cache Support  */
 void         ssl_scache_init(server_rec *, pool *);
-void         ssl_scache_kill(void);
-void         ssl_scache_store(server_rec *, SSL_SESSION *, int);
+void         ssl_scache_kill(server_rec *);
+BOOL         ssl_scache_store(server_rec *, SSL_SESSION *, int);
 SSL_SESSION *ssl_scache_retrieve(server_rec *, UCHAR *, int);
 void         ssl_scache_remove(server_rec *, SSL_SESSION *);
 void         ssl_scache_expire(server_rec *, time_t);
 void         ssl_scache_status(server_rec *, pool *, void (*)(char *, void *), void *);
 char        *ssl_scache_id2sz(UCHAR *, int);
 void         ssl_scache_dbm_init(server_rec *, pool *);
-void         ssl_scache_dbm_kill(void);
-void         ssl_scache_dbm_store(server_rec *, ssl_scinfo_t *);
+void         ssl_scache_dbm_kill(server_rec *);
+BOOL         ssl_scache_dbm_store(server_rec *, ssl_scinfo_t *);
 void         ssl_scache_dbm_retrieve(server_rec *, ssl_scinfo_t *);
 void         ssl_scache_dbm_remove(server_rec *, ssl_scinfo_t *);
 void         ssl_scache_dbm_expire(server_rec *, time_t);
 void         ssl_scache_dbm_status(server_rec *, pool *, void (*)(char *, void *), void *);
 void         ssl_scache_shm_init(server_rec *, pool *);
-void         ssl_scache_shm_kill(void);
-void         ssl_scache_shm_store(server_rec *, ssl_scinfo_t *);
+void         ssl_scache_shm_kill(server_rec *);
+BOOL         ssl_scache_shm_store(server_rec *, ssl_scinfo_t *);
 void         ssl_scache_shm_retrieve(server_rec *, ssl_scinfo_t *);
 void         ssl_scache_shm_remove(server_rec *, ssl_scinfo_t *);
 void         ssl_scache_shm_expire(server_rec *, time_t);
@@ -701,7 +701,7 @@ BOOL         ssl_mutex_sem_acquire(void);
 BOOL         ssl_mutex_sem_release(void);
 
 /*  Logfile Support  */
-void         ssl_log_open(server_rec *, pool *);
+void         ssl_log_open(server_rec *, server_rec *, pool *);
 BOOL         ssl_log_applies(server_rec *s, int level);
 void         ssl_log(server_rec *, int, const char *, ...);
 void         ssl_die(void);
