@@ -395,6 +395,10 @@ static void ssl_ext_ms_display_cb(char *str, void *_r)
 
 static void ssl_ext_ms_display(request_rec *r, int no_table_report, int short_report)
 {
+    SSLSrvConfigRec *sc = mySrvConfig(r->server);
+
+    if (sc == NULL)
+        return;
     ap_rputs("<hr>\n", r);
     ap_rputs("<table cellspacing=0 cellpadding=0>\n", r);
     ap_rputs("<tr><td bgcolor=\"#000000\">\n", r);
