@@ -77,11 +77,11 @@ void ssl_mutex_init(server_rec *s, pool *p)
 
     if (mc->nMutexMode == SSL_MUTEXMODE_FILE) {
         ssl_mutex_file_create(s, p);
-        ap_register_cleanup(p, (void *)s, ssl_mutex_file_remove, ap_null_cleanup);
+        ap_register_cleanup(p, (void *)s, ssl_mutex_file_remove, ssl_mutex_file_remove);
     }
     else if (mc->nMutexMode == SSL_MUTEXMODE_SEM) {
         ssl_mutex_sem_create(s, p);
-        ap_register_cleanup(p, (void *)s, ssl_mutex_sem_remove, ap_null_cleanup);
+        ap_register_cleanup(p, (void *)s, ssl_mutex_sem_remove, ssl_mutex_sem_remove);
     }
     return;
 }
