@@ -734,7 +734,10 @@ void ssl_scache_shm_kill(server_rec *s)
 {
     SSLModConfigRec *mc = myModConfig();
 
-    ap_mm_destroy(mc->pSessionCacheDataMM);
+    if (mc->pSessionCacheDataMM != NULL) {
+        ap_mm_destroy(mc->pSessionCacheDataMM);
+        mc->pSessionCacheDataMM = NULL;
+    }
     return;
 }
 
